@@ -1,4 +1,5 @@
 from lxml import html
+from lxml import etree
 import re
 
 re_type = type(re.compile(''))
@@ -15,6 +16,9 @@ class Page(object):
         else:
             self.root = html.fromstring(content)
 
+    def __repr__(self):
+        return etree.tostring(self.root, pretty_print = True)
+
     def css_select(self, selector):
         '''
         Takes a string as a CSS selector, and returns all the elements
